url_home = 'https://ematricula.ucr.ac.cr/ematricula/admin/showAdminLogin.do'
url_login = 'https://ematricula.ucr.ac.cr/ematricula/admin/loginAdmin.do'
url_listado = 'https://ematricula.ucr.ac.cr/ematricula/admin/profesorExpedienteEstud.do'
url_comentarios = 'https://ematricula.ucr.ac.cr/ematricula/admin/showComentariosProfEstud.do?c={}'
url_notas = 'https://ematricula.ucr.ac.cr/ematricula/admin/nivelAvance.do?c={}'
data = {'user': '', 'password': ''}
DEBUG = True

detalle_cursos = [
    {'sigla': 'EF-D', 'curso.py': 'ACTIVIDAD DEPORTIVA', 'creditos': 0, 'semestre': 1},
    {'sigla': 'EG-CA', 'curso.py': 'CURSO DE ARTE', 'creditos': 2, 'semestre': 1},
    {'sigla': 'EG-I', 'curso.py': 'CURSO INTEGRADO DE HUMANIDADES I',
     'creditos': 6, 'semestre': 1},
    {'sigla': 'MA1001', 'curso.py': 'CÁLCULO I', 'creditos': 3, 'semestre': 1},
    {'sigla': 'QU0100', 'curso.py': 'QUÍMICA GENERAL I',
     'creditos': 3, 'correquisitos': ['QU0101'], 'semestre': 1},
    {'sigla': 'QU0101', 'curso.py': 'LABORATORIO DE QUÍMICA GENERAL I',
     'creditos': 1, 'correquisitos': ['QU0100'], 'semestre': 1},
    {'sigla': 'RP-1', 'curso.py': 'REPERTORIO', 'creditos': 3, 'semestre': 1},
    {'sigla': 'EG-II', 'curso.py': 'CURSO INTEGRADO DE HUMANIDADES II',
     'creditos': 6, 'semestre': 2},
    {'sigla': 'FS0210', 'curso.py': 'FÍSICA GENERAL I', 'creditos': 3,
     'requisitos': ['MA1001'], 'correquisitos': ['FS0211'], 'semestre': 2},
    {'sigla': 'FS0211', 'curso.py': 'LABORATORIO DE FÍSICA GENERAL I', 'creditos': 1,
     'requisitos': ['MA1001'], 'correquisitos': ['FS0210'], 'semestre': 2},
    {'sigla': 'II0201', 'curso.py': 'INTRODUCCIÓN A LA INGENIERÍA INDUSTRIAL',
     'creditos': 2, 'semestre': 2},
    {'sigla': 'MA1002', 'curso.py': 'CÁLCULO II', 'creditos': 4,
     'requisitos': ['MA1001'], 'semestre': 2},
    {'sigla': 'QU0102', 'curso.py': 'QUÍMICA GENERAL II', 'creditos': 3, 'requisitos': [
        'QU0100', 'QU0101'], 'correquisitos': ['QU0103'], 'semestre': 2},
    {'sigla': 'QU0103', 'curso.py': 'LABORATORIO DE QUÍMICA GENERAL II', 'creditos': 1,
     'requisitos': ['QU0100', 'QU0101'], 'correquisitos': ['QU0102'], 'semestre': 2},
    {'sigla': 'CI0202', 'curso.py': 'PRINCIPIOS DE INFORMÁTICA',
     'creditos': 4, 'requisitos': ['MA0205'], 'semestre': 3},
    {'sigla': 'FS0310', 'curso.py': 'FÍSICA GENERAL II', 'creditos': 3, 'requisitos': [
        'FS0210', 'FS0211', 'MA1002'], 'correquisitos': ['FS0311'], 'semestre': 3},
    {'sigla': 'FS0311', 'curso.py': 'LABORATORIO DE FÍSICA GENERAL II', 'creditos': 1,
     'requisitos': ['FS0210', 'FS0211', 'MA1002'], 'correquisitos': ['FS0310'], 'semestre': 3},
    {'sigla': 'II0306', 'curso.py': 'PROBABILIDAD Y ESTADÍSTICA',
     'creditos': 3, 'requisitos': ['MA1002'], 'semestre': 3},
    {'sigla': 'MA1003', 'curso.py': 'CÁLCULO III', 'creditos': 4,
     'requisitos': ['MA1002'], 'correquisitos': ['MA1004'], 'semestre': 3},
    {'sigla': 'MA1004', 'curso.py': 'ÁLGEBRA LINEAL', 'creditos': 3, 'semestre': 3},
    {'sigla': 'FS0410', 'curso.py': 'FÍSICA GENERAL III', 'creditos': 3, 'requisitos': [
        'FS0310', 'FS0311', 'MA1003'], 'correquisitos': ['FS0411'], 'semestre': 4},
    {'sigla': 'FS0411', 'curso.py': 'LABORATORIO DE FÍSICA GENERAL III', 'creditos': 1,
     'requisitos': ['FS0310', 'FS0311', 'MA0450'], 'correquisitos': ['FS0410'], 'semestre': 4},
    {'sigla': 'II0401', 'curso.py': 'INVESTIGACIÓN DE OPERACIONES',
     'creditos': 3, 'requisitos': ['II0306', 'MA1004'], 'semestre': 4},
    {'sigla': 'II0402', 'curso.py': 'INGENIERÍA DE CALIDAD I',
     'creditos': 2, 'requisitos': ['II0306'], 'semestre': 4},
    {'sigla': 'II0501', 'curso.py': 'TECNOLOGÍAS DE INFORMACIÓN',
     'creditos': 2, 'requisitos': ['CI0202'], 'semestre': 4},
    {'sigla': 'IM0202', 'curso.py': 'DIBUJO I', 'creditos': 3,
     'requisitos': ['FS0210', 'MA1001'], 'semestre': 4},
    {'sigla': 'MA1005', 'curso.py': 'ECUACIONES DIFERENCIALES',
     'creditos': 4, 'requisitos': ['MA1002', 'MA1004'], 'semestre': 4},
    {'sigla': 'IE0303', 'curso.py': 'ELECTROTECNIA I', 'creditos': 3,
     'requisitos': ['FS0310', 'FS0311', 'MA1003'], 'semestre': 5},
    {'sigla': 'II0302', 'curso.py': 'DISEÑO DEL TRABAJO E INGENIERÍA DE FACTORES HUMANOS',
     'creditos': 3, 'requisitos': ['II0306'], 'semestre': 5},
    {'sigla': 'II0502', 'curso.py': 'INGENIERÍA DE CALIDAD II',
     'creditos': 4, 'requisitos': ['II0402'], 'semestre': 5},
    {'sigla': 'II0503', 'curso.py': 'SIMULACIÓN', 'creditos': 3,
     'requisitos': ['CI0202', 'II0401'], 'semestre': 5},
    {'sigla': 'II0504', 'curso.py': 'ADMINISTRACIÓN FINANCIERA Y CONTABLE I',
     'creditos': 2, 'requisitos': ['II0201'], 'semestre': 5},
    {'sigla': 'IM0207', 'curso.py': 'MECÁNICA I', 'creditos': 3, 'requisitos': [
        'FS0210', 'FS0211', 'IM0202', 'MA1002'], 'semestre': 5},
    {'sigla': 'II0601', 'curso.py': 'GESTIÓN DE CALIDAD',
     'creditos': 4, 'requisitos': ['II0502'], 'semestre': 6},
    {'sigla': 'II0603', 'curso.py': 'SISTEMAS AUTOMATIZADOS DE MANUFACTURA', 'creditos': 3,
     'requisitos': ['FS0410', 'FS0411', 'IE0303', 'II0302', 'II0503', 'II0504'], 'semestre': 6},
    {'sigla': 'II0604', 'curso.py': 'ADMINISTRACIÓN FINANCIERA Y CONTABLE II',
     'creditos': 2, 'requisitos': ['II0504'], 'semestre': 6},
    {'sigla': 'II0605', 'curso.py': 'LOGÍSTICA DE LA CADENA DEL VALOR I',
     'creditos': 3, 'requisitos': ['II0401'], 'semestre': 6},
    {'sigla': 'II0606', 'curso.py': 'TERMOFLUIDOS', 'creditos': 3, 'requisitos': [
        'FS0310', 'FS0311', 'IE0303', 'IM0207', 'QU0102', 'QU0103'], 'semestre': 6},
    {'sigla': 'II0701', 'curso.py': 'DISEÑO DE SISTEMAS DE INFORMACIÓN',
     'creditos': 3, 'requisitos': ['II0501'], 'semestre': 6},
    {'sigla': 'II0602', 'curso.py': 'DISEÑO DE EXPERIMENTOS',
     'creditos': 3, 'requisitos': ['II0601'], 'semestre': 7},
    {'sigla': 'II0702', 'curso.py': 'COMPORTAMIENTO ORGANIZACIONAL',
     'creditos': 2, 'requisitos': ['II0302'], 'semestre': 7},
    {'sigla': 'II0703', 'curso.py': 'INGENIERÍA DE OPERACIONES', 'creditos': 4,
     'requisitos': ['II0603', 'II0604', 'II0605', 'II0701'], 'semestre': 7},
    {'sigla': 'II0704', 'curso.py': 'INGENIERÍA ECONÓMICA Y FINANCIERA', 'creditos': 3,
     'requisitos': ['II0604'], 'correquisitos': ['II0703'], 'semestre': 7},
    {'sigla': 'II0705', 'curso.py': 'LOGÍSTICA DE LA CADENA DEL VALOR II',
     'creditos': 4, 'requisitos': ['II0605'], 'semestre': 7},
    {'sigla': 'SR-I', 'curso.py': 'SEMINARIO DE REALIDAD NACIONAL I',
     'creditos': 2, 'semestre': 7},
    {'sigla': 'II0802', 'curso.py': 'INGENIERÍA DE PROCESOS DE NEGOCIO',
     'creditos': 4, 'requisitos': ['II0702'], 'semestre': 8},
    {'sigla': 'II0803', 'curso.py': 'DISEÑO DE PRODUCTO', 'creditos': 3,
     'requisitos': ['II0704'], 'correquisitos': ['II0804'], 'semestre': 8},
    {'sigla': 'II0804', 'curso.py': 'GESTIÓN DE PROYECTOS',
     'creditos': 3, 'requisitos': ['II0704'], 'semestre': 8},
    {'sigla': 'II0805', 'curso.py': 'DISTRIBUCIÓN Y LOCALIZACIÓN DE INSTALACIONES',
     'creditos': 4, 'requisitos': ['II0703', 'II0705'], 'semestre': 8},
    {'sigla': 'II0806', 'curso.py': 'METROLOGÍA Y NORMALIZACIÓN',
     'creditos': 3, 'requisitos': ['II0602'], 'semestre': 8},
    {'sigla': 'SR-II', 'curso.py': 'SEMINARIO DE REALIDAD NACIONAL II',
     'creditos': 2, 'semestre': 8},
    {'sigla': 'II0801', 'curso.py': 'INGENIERÍA DE SERVICIOS', 'creditos': 3,
     'requisitos': ['II0601', 'II0703', 'II0705'], 'semestre': 9},
    {'sigla': 'II0902', 'curso.py': 'PROYECTO INDUSTRIAL', 'creditos': 3, 'semestre': 9},
    {'sigla': 'II0904', 'curso.py': 'INGENIERÍA AMBIENTAL', 'creditos': 3,
     'requisitos': ['II0601', 'II0804'], 'semestre': 9},
    {'sigla': 'II0905', 'curso.py': 'INGENIERÍA DE MANUFACTURA', 'creditos': 3,
     'requisitos': ['II0703', 'II0803', 'II0805'], 'semestre': 9},
    {'sigla': 'II0906', 'curso.py': 'GESTIÓN DE MANTENIMIENTO', 'creditos': 3,
     'requisitos': ['II0601', 'II0603', 'II0606'], 'semestre': 9},
    {'sigla': 'OPT408a', 'curso.py': 'BLOQUE OPTATIVO 408', 'creditos': 3, 'semestre': 9},
    {'sigla': 'II1001', 'curso.py': 'RESPONSABILIDAD SOCIAL',
     'creditos': 2, 'requisitos': ['II0904'], 'semestre': 10},
    {'sigla': 'II9500', 'curso.py': 'INVESTIGACIÓN DIRIGIDA I',
     'creditos': 0, 'requisitos': ['II0902'], 'semestre': 10},
    {'sigla': 'OPT408b', 'curso.py': 'IBLOQUE OPTATIVO 408',
     'creditos': 3, 'semestre': 10},
    {'sigla': 'II9501', 'curso.py': 'INVESTIGACIÓN DIRIGIDA II',
     'creditos': 0, 'semestre': 11},
    {'sigla': 'II9502', 'curso.py': 'INVESTIGACIÓN DIRIGIDA III',
     'creditos': 0, 'semestre': 12}
]
